import { FormGroup } from '@angular/forms';
import type { Observable } from 'rxjs';
import type { IDynamicControl } from '../interfaces/dynamic-control';
import type { IDynamicForm } from '../interfaces/dynamic-form';
import type { IDynamicOverride } from '../interfaces/dynamic-override';
export declare class DynamicForm {
    private controls;
    private overrides;
    private formGroup;
    actions: {
        save?: boolean;
        close?: boolean;
        reset?: boolean;
    };
    private onSaveSubject;
    private onCloseSubject;
    private onResetSubject;
    private onChangeSubject;
    private formChange;
    constructor(config: IDynamicForm);
    /**
     * Get observable for save event
     * @returns Observable
     */
    onSave(): Observable<unknown>;
    /**
     * Get observable for close event
     * @returns Observable
     */
    onClose(): Observable<unknown>;
    /**
     * Get observable for reset event
     * @returns Observable
     */
    onReset(): Observable<unknown>;
    /**
     * Get observable for change event
     * @returns Observable
     */
    onChange(): Observable<unknown>;
    /**
     * Trigger save event
     */
    save(): void;
    /**
     * Trigger close event
     */
    close(): void;
    /**
     * Trigger reset event
     */
    reset(): void;
    /**
     * Reload labels
     */
    reloadLabels(): void;
    /**
     * Reload form
     */
    reloadForm(_formGroup: FormGroup, _overrides: IDynamicOverride[]): void;
    /**
     * Clean form / reset
     */
    cleanForm(): void;
    /**
     * Get FormGroup
     */
    get FormGroup(): FormGroup;
    /**
     * Get Controls
     */
    get Controls(): IDynamicControl[];
    /**
     * Init form
     */
    private initForm;
    /**
     * Map controls with overrides
     */
    private mapControls;
}
